==> invivoPKfit_2.0.1.tar.gz: invivoPKfit/R/globals.R <==
utils::globalVariables(
  c("param_value_type",
    "Reference",
    "Route",
    "Value",
    "Dose",
    "Time",
    "Data.Analyzed",
    "LogLikelihood",
    "AIC",
    "Compound",
    "Route",
    "LOQ",
    "iv",
    "Time.Days",
    ".",
    "CAS",
    "N.Obs.Ref",
    "Reference",
    "Species",
    "Value.Norm",
    "id",
    "nca.complete",
    "Vd.iv",
    "Mean.iv.Dose",
    "Vd.po",
    "Mean.po.Dose",
    "kelim",
    "Vdist",
    "Fgutabs",
    "kgutabs",
    "V1",
    "Ralphatokelim",
    "Fbetaofalpha",
    "model.type",
    "CLtot",
    "Css",
    "halflife",
    "tpeak.oral",
    "Cpeak.oral.1mgkg",
    "param.value.type",
    "k21",
    "k12",
    "time",
    "Ccompartment",
    "sigma.ref",
    "Max.Time.Days",
    "Time.Steps.PerHour",
    "mu",
    "var",
    "Dose.nominal",
    "Compound",
    "Source",
    "Dose.nominal.units.type",
    "studyid.nominal",
    "Model",
    "Usable",
    "pred",
    "LOQ",
    "L.O.Q.",
    "LOQ.",
    "Reference.y",
    "Media",
    "n",
    "J",
    "sigma",
    "value",
    "AUC_fold_range",
    "AUC_infinity",
    "AUC_infinity.nca",
    "AUC_infinity.tkstats",
    "AUTO_UNITS",
    "A_iv_unit",
    "A_oral_unit",
    "B_iv_oral",
    "B_iv.unit",
    "B_iv_unit",
    "B_oral_unit",
    "CLtot/Fgutabs",
    "Chemical",
    "Cmax",
    "Cmax_fold_range",
    "Conc",
    "Conc.Units",
    "Conc_tmp",
    "Conc_tmp.Units",
    "Conc_SD_tmp",
    "Conc_SD",
    "Conc_SD_trans",
    "Conc_est",
    "Conc_set",
    "Conc_set_SD",
    "Conc_trans",
    "Conc_trans.Units",
    "Detect",
    "Dose.Units",
    "Fgutabs_Vdist",
    "LOQ_orig",
    "NEW_UNITS",
    "N_Subjects",
    "Rblood2plasma",
    "Series_ID",
    "TKstats",
    "TKstats_wide",
    "Time.Units",
    "Time.Units_orig",
    "TimeFrom",
    "TimeTo",
    "Time_trans",
    "Time_trans.Units",
    "Value.Units",
    "Value_SD",
    "Value_SD_orig",
    "administration_route_normalize",
    "alerts",
    "analyte_casrn",
    "analyte_dtxsid",
    "analyte_name_original",
    "approx",
    "c_data",
    "caller_env",
    "coef",
    "coefs_tibble",
    "coefs_vector",
    "conc",
    "conc_medium_normalized",
    "conc_sd_normalized",
    "conc_time_id",
    "const_pars",
    "conversion",
    "data_flag",
    "data_sigma_group",
    "dnorm",
    "document_id",
    "dose_level_corrected",
    "error_group",
    "error_group_value",
    "exclude fit",
    "fit_decision",
    "fit_reason",
    "hessian_mat",
    "interpolated",
    "loq",
    "lower_bound",
    "maxTime",
    "max_conc",
    "near_flat",
    "pred_below_loq",
    "Parameter",
    "Mouse", "Monkey",
    "variable",
    "Tissue",
    "RMSE",
    "median",
    "model",
    "model_name",
    "model_1comp",
    "model_2comp",
    "model_flat",
    "model_1comp_cl_rest",
    "model_1comp_cl_nonrest",
    "model_fun",
    "modelfun",
    "method",
    "N_ROW",
    "estimate",
    "n_detect",
    "n_par",
    "n_par_opt",
    "n_sigma",
    "n_subjects_in_series npar",
    "ngatend",
    "nhatend",
    "hev",
    "observation_plot",
    "observations",
    "optimize_param",
    "param_name",
    "param_sd_z",
    "param_units",
    "param_value",
    "pnorm",
    "predict",
    "predicted",
    "predicted_plot",
    "predictions",
    "runif",
    "sd",
    "sds",
    "sds_tibble",
    "series_id",
    "setNames",
    "sigma.value",
    "sigma.value_sd",
    "sigma_value",
    "species",
    "start",
    "status_data_info",
    "status_fit",
    "status_init",
    "status_prefit",
    "status_preprocess",
    "study_id",
    "subject_id",
    "tfirst_detect",
    "time_conversions",
    "time_hr",
    "time_units",
    "tk_fun",
    "tkstats_df",
    "tlast_detect",
    "tmax",
    "to_perhour",
    "uniroot",
    "upper_bound",
    "use_param ",
    "weight_kg",
    "exclude",
    "fit",
    "n_subjects_in_series",
    "npar",
    "use_param",
    "administration_route_normalized",
    "convcode",
    "xtime",
    "design",
    "Q_totli",
    "Fup",
    "Clint",
    "Q_gfr",
    "pLOQ",
    "Conc_nca.Units",
    "Dose_nca",
    "Conc_nca",
    "fk_extraction_document_id",
    "invivPK_dose_level",
    "fk_subject_id",
    "fk_series_id",
    "fk_study_id",
    "n_subjects_normalized",
    "invivPK_conc",
    "invivPK_conc_sd",
    "invivPK_loq",
    "Dose_tmp",
    "data_descr",
    "conc_mean",
    "conc_sd",
    "foldCOnc",
    "Fold_Error",
    "both_within",
    "data_outside",
    "Study_ID",
    "fit_data",
    "foldConc",
    "param_name_sd",
    "param_sd",
    "preds_below_loq",
    "Conc_est_tmp",
    "coefs_opt_vector",
    "coefs_const_vector",
    "sd_tbl",
    "sd_alert"
  )
)

==> invivoPKfit_2.0.2.tar.gz: invivoPKfit/R/globals.R <==
utils::globalVariables(
  c(
    # Data variables
    "DATA_GROUP_ID",
    "Chemical",
    "Species",
    "Reference",
    "Chemical_Name",
    "Route",
    "Media",
    "Dose",
    "Dose.Units",
    "Series_ID",
    "Study_ID",
    "Subject_ID",
    "Time",
    "Time.Units",
    "Time_trans",
    "Time_trans.Units",
    "LOQ",
    "pLOQ",
    "Detect",
    "exclude",
    "Conc",
    "Conc_SD",
    "Conc.Units",
    "Conc_trans",
    "Conc_SD_trans",
    "Conc_trans.Units",
    "Conc_est",
    "Conc_est_tmp",
    "Conc_set",
    "Conc_set_SD",
    "N_Subjects",
    "Conc_tmp",
    "Conc_tmp.Units",
    "Conc_SD_tmp",
    "Conc_nca",
    "Conc_nca.Units",
    "Weight",
    "Weight.Units",
    # Built in data
    "status_init",
    "status_fit",
    "time_units",
    "time_conversions",
    "status_preprocess",
    "status_data_info",
    "status_prefit",
    "model_1comp",
    "model_2comp",
    "model_flat",
    "model_httk_gas_pbtk",
    #
    "model",
    "method",
    "modelfun",
    "pred_fun",
    "pred_fun_args",
    "fit_decision",
    "n_par",
    "n_sigma",
    "n_detect",
    "n_par_opt",
    "used_par_na",
    "param_name",
    "estimate",
    "param_units",
    "ngatend",
    "nhatend",
    "hev",
    "method",
    "value",
    "lower_bound",
    "upper_bound",
    "convergence",
    "optimize_param",
    "use_param",
    "conc_mean",
    "tmax",
    "tlast_detect",
    "tfirst_detect",
    "data_flag",
    "to_perhour",
    "max_conc",
    "sd_tbl",
    "param_sd",
    "sd_alert",
    "coefs_tibble",
    "suppress.messages",
    "data_grp",
    "data_grp_vars",
    # preprocess
    "LOQ_orig",
    "Value",
    "Value.Units",
    "Value_SD",
    "Value_SD_orig",
    "Time.Units_orig",
    "AUTO_UNITS",
    "NEW_UNITS",
    # NCA or tkstats
    "CLtot",
    "CLtot/Fgutabs",
    "AUC_infinity",
    "Cmax",
    "Cmax_fold_range",
    "AUC_fold_range",
    "tkstats_fun",
    "tkstats_fun_args",
    "TKstats",
    # eval_tkstats
    "new_flat",
    "preds_below_loq",
    "param_sd_z",
    "param_value",
    "AUC_infinity.nca",
    "AUC_infinity.tkstats",
    # get_winning_model
    "RMSE",
    "near_flat",
    "preds_below_loq",
    # get_hessian
    "coefs_vector",
    "data_sigma_group",
    "observations",
    "coefs_opt_vector",
    "coefs_opt_vector_id",
    "coefs_const_vector",
    # get_starts
    "value",
    "variable",
    # twofold_test
    "data_descr",
    "conc_sd",
    "foldConc",
    "Fold_Error",
    "fit",
    "fit_reason",
    # CvTdb variables
    "analyzed_chem_dtxsid",
    "analyzed_chem_name_original",
    "analyzed_chem_dtxsid",
    "analyzed_chem_casrn",
    "species",
    "fk_extraction_document_id",
    "conc_medium_normalized",
    "administration_route_normalized",
    "dose_level_normalized",
    "fk_subject_id",
    "fk_series_id",
    "fk_study_id",
    "conc_time_id",
    "n_subjects_normalized",
    "weight_kg",
    "time_hr",
    "conc",
    "conc_sd",
    "loq",
    "N_ROW",
    # external function definitions
    "approx",
    "sd",
    "predict",
    "pnorm",
    "rnorm",
    "coef",
    "dnorm",
    "setNames",
    "median",
    "start",
    "uniroot",
    ".progress",
    ".stop",
    add = FALSE
  )
)
